@@ -1,7 +1,7 @@
 # encoding: utf-8
 
-require 'hocon/impl'
-require 'hocon/config_mergeable'
+require_relative '../../hocon/impl'
+require_relative '../../hocon/config_mergeable'
 
 class Hocon::Impl::MergeableValue < Hocon::ConfigMergeable
   # TODO
